@@ -5,8 +5,7 @@ The statistics are obtained by connecting to and querying the Memcached.
 """
 
 import re
-import sys
-import telnetlib
+import os
 import util
 
 __author__ = "Ali Onur Uyar"
@@ -19,7 +18,7 @@ __email__ = "aouyar at gmail.com"
 __status__ = "Development"
 
 
-connTimeout = 5
+defaultMemcachedPort = 11211
 
 
 class MemcachedInfo:
@@ -28,17 +27,34 @@ class MemcachedInfo:
 
     """
 
-    def __init__(self, host='127.0.0.1', port=11211, autoInit=True):
+    def __init__(self, host='127.0.0.1', port=defaultMemcachedPort, 
+                 socket_file=None, timeout=None, autoInit=True):
         """Initialize connection to Memcached.
         
-        @param host:     Memcached Host
-        @param port:     Memcached Port
-        @param autoInit: If True connect to Memcached on init.
+        @param host:        Memcached Host for TCP connections.
+        @param port:        Memcached Port for TCP connections.
+        @param socket_file: Memcached Socket File Path for UNIX Socket connections.
+        @param timeout:     Memcached Socket Timeout in seconds.
+        @param autoInit:    If True connect to Memcached on init.
 
         """
         self._conn = None
-        self._host = host or '127.0.0.1'
-        self._port = int(port) or 11211
+        if socket_file is not None:
+            self._host = None
+            self._port = None
+            self._socketFile = socket_file
+            self._instanceName = ("Memcached Instance on socket file %s" 
+                                  % self._socketFile)
+        else:
+            self._host = host or '127.0.0.1'
+            self._port = int(port or defaultMemcachedPort)
+            self._socketFile = None
+            self._instanceName = ("Memcached Instance on host %s and port %s"
+                                  % (self._host, self._port))
+        if timeout is not None:
+            self._timeout = float(timeout)
+        else:
+            self._timeout = None
         if autoInit:
             self._connect()
     
@@ -49,18 +65,19 @@ class MemcachedInfo:
 
     def _connect(self):
         """Connect to Memcached."""
+        if self._socketFile is not None:
+            if not os.path.exists(self._socketFile):
+                raise Exception("Socket file (%s) for Memcached Instance not found."
+                                % self._socketFile)
         try:
-            if sys.version_info[:2] >= (2,6):
-                self._conn = telnetlib.Telnet(self._host, self._port, 
-                                              connTimeout)
+            if self._timeout is not None:
+                self._conn = util.Telnet(self._host, self._port, self._socketFile, 
+                                         timeout)
             else:
-                self._conn = telnetlib.Telnet(self._host, self._port)
-        except:
-            raise Exception(
-                "Connection to Memcached Instance on host %s and port %d failed."
-                % (self._host, self._port)
-                )
-    
+                self._conn = util.Telnet(self._host, self._port, self._socketFile)
+        except:     
+            raise Exception("Connection to %s failed." % self._instanceName)
+            
     def _sendStatCmd(self,  cmd):
         """Send stat command to Memcached Server and return response lines.
         
@@ -71,22 +88,17 @@ class MemcachedInfo:
         try:
             self._conn.write("%s\r\n" % cmd)
             regex = re.compile('^(END|ERROR)\r\n', re.MULTILINE)
-            (idx, mobj, text) = self._conn.expect([regex,], connTimeout) #@UnusedVariable
+            (idx, mobj, text) = self._conn.expect([regex,], self._timeout) #@UnusedVariable
         except:
-            raise Exception("Communication with Memcached Instance on "
-                            "host %s and port %d failed." % 
-                            (self._host, self._port))
+            raise Exception("Communication with %s failed" % self._instanceName)
         if mobj is not None:
             if mobj.group(1) == 'END':
                 return text.splitlines()[:-1]
             elif mobj.group(1) == 'ERROR':
-                raise Exception("Protocol error in communication with "
-                            "Memcached Instance on host %s and port %d."
-                            % (self._host, self._port))
+                raise Exception("Protocol error in communication with %s."
+                                % self._instanceName)
         else:
-            raise Exception("Connection with Memcached Instance on "
-                            "host %s and port %d timed out."
-                            % (self._host, self._port))
+            raise Exception("Connection with %s timed out." % self._instanceName)
     def _parseStats(self, lines, parse_slabs = False):
         """Parse stats output from memcached and return dictionary of stats-
         
