@@ -6,6 +6,8 @@ import sys
 import re
 import subprocess
 import urllib, urllib2
+import socket
+import telnetlib
 
 
 __author__ = "Ali Onur Uyar"
@@ -30,16 +32,20 @@ def parse_value(val, parsebool=False):
     @return:          Value of type int, float or str.
         
     """
-    if re.match('-{0,1}\d+$',  str(val)):
-            return int(val)
-    elif re.match('-{0,1}\d*\.\d+$',  str(val)):
+    try:
+        return int(val)
+    except ValueError:
+        pass
+    try:
         return float(val)
-    elif parsebool and re.match('yes|on', str(val), re.IGNORECASE):
-        return True
-    elif parsebool and re.match('no|off', str(val), re.IGNORECASE):
-        return False
-    else:
-        return val
+    except:
+        pass
+    if parsebool:
+        if re.match('yes|on', str(val), re.IGNORECASE):
+            return True
+        elif re.match('no|off', str(val), re.IGNORECASE):
+            return False
+    return val
     
 
 def safe_sum(seq):
@@ -207,7 +213,7 @@ class SoftwareVersion(tuple):
                                 " of integers.")
         
     def __str__(self):
-        """
+        """Returns string representation of version.
         
         """
         return self._versionstr
@@ -335,3 +341,56 @@ class TableFilter:
             else:
                 result.append(row)
         return result
+    
+
+class Telnet(telnetlib.Telnet):
+    
+    __doc__ = telnetlib.Telnet.__doc__
+    
+    def __init__(self, host=None, port=0, socket_file=None, 
+                 timeout=socket.getdefaulttimeout()):
+        """Constructor.
+
+        When called without arguments, create an unconnected instance.
+        With a host argument, it connects the instance using TCP; port number 
+        and timeout are optional, socket_file must be None.
+        
+        With a socket_file argument, it connects the instance using
+        named socket; timeout is optional and host must be None.
+        
+        """
+        telnetlib.Telnet.__init__(self, timeout=timeout)
+        if host is not None or socket_file is not None:
+            self.open(host, port, socket_file, timeout=timeout)
+    
+    def open(self, host=None, port=0, socket_file=None, 
+             timeout=socket.getdefaulttimeout()):
+        """Connect to a host.
+
+        With a host argument, it connects the instance using TCP; port number 
+        and timeout are optional, socket_file must be None. The port number
+        defaults to the standard telnet port (23).
+        
+        With a socket_file argument, it connects the instance using
+        named socket; timeout is optional and host must be None.
+
+        Don't try to reopen an already connected instance.
+        
+        """
+        self.socket_file = socket_file
+        if host is not None:
+            if sys.version_info[:2] >= (2,6):
+                telnetlib.Telnet.open(self, host, port, timeout)
+            else:
+                telnetlib.Telnet.open(self, host, port)
+        elif socket_file is not None:
+            self.eof = 0
+            self.host = host
+            self.port = port
+            self.timeout = timeout
+            self.sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+            self.sock.settimeout(timeout)
+            self.sock.connect(socket_file)
+        else:
+            raise TypeError("Either host or socket_file argument is required.")      
+        
\ No newline at end of file
